src/hbcore/utils/hbwidgetloader.cpp
branchGCC_SURGE
changeset 15 f378acbc9cfb
parent 7 923ff622b8b9
child 21 4633027730f5
child 34 ed14f46c0e55
--- a/src/hbcore/utils/hbwidgetloader.cpp	Thu Jul 15 14:03:49 2010 +0100
+++ b/src/hbcore/utils/hbwidgetloader.cpp	Thu Jul 22 16:36:53 2010 +0100
@@ -22,6 +22,9 @@
 ** Nokia at developer.feedback@nokia.com.
 **
 ****************************************************************************/
+#ifndef HB_BIN_CSS
+#define HB_USETHEMESERVER
+#endif
 
 #include "hbwidgetloader_p.h"
 #include "hbwidgetloadersyntax_p.h"
@@ -29,7 +32,9 @@
 
 #include "hbinstance.h"
 #include "hbtheme_p.h"
+#ifdef HB_USETHEMESERVER
 #include "hbthemeclient_p.h"
+#endif
 
 #include <QtDebug>
 #include <QFile>
@@ -51,7 +56,7 @@
 
 #define hbInstance (HbInstance::instance())
 
 // cache at the client side to store the mesh items.
 // key used here is the filename+layoutname+sectionname.
 
 typedef QHash<QString,HbWidgetLoader::LayoutDefinition*> ClientHashForLayoutDefs;
@@ -63,11 +68,11 @@
 Q_GLOBAL_STATIC(QStringList, filesNotPresent)
 
 // Layout caching
-static HbWidgetLoader::LayoutDefinition *staticCacheLayout = NULL;
-static QString staticCacheFileName = QString();
-static QString staticCacheName = QString();
-static QString staticCacheSection = QString();
-static QDateTime staticCacheModified = QDateTime();
+static HbWidgetLoader::LayoutDefinition *staticCacheLayout = 0;
+static QString staticCacheFileName;
+static QString staticCacheName;
+static QString staticCacheSection;
+static QDateTime staticCacheModified;
 
 class HbWidgetLoaderPrivate
 {
@@ -141,14 +146,14 @@
 /*!
     Loads and processes a WidgetML file.
 
-    If the widget already has a layout assumes it's HbMeshLayout.
-    If the widget doesn't have a layout creates HbMeshLayout and sets it to widget.
+    If the widget already has a layout assumes it's HbAnchorLayout.
+    If the widget doesn't have a layout creates HbAnchorLayout and sets it to widget.
     Creates the anchor edge attachments based on WidgetML.
 
     \param fileName file to be processed.
     \param name the name of the layout to be loaded.
     \param section space separated route to section, that you want to load.
-    \param storage specifies where to store the mesh items.
+    \param storage specifies where to store the anchor items.
     \return true if file was loaded and processed successfully.
 */
 bool HbWidgetLoader::load(
@@ -237,6 +242,12 @@
     delete mActions;
 }
 
+#ifdef HB_BIN_CSS
+void HbWidgetLoaderPrivate::setWidget( HbWidget* widget )
+{
+    Q_UNUSED(widget)
+}
+#else
 /*!
     \internal
 */
@@ -246,6 +257,7 @@
     mActions->mWidget = widget;
     mActions->mCurrentProfile = HbDeviceProfile::profile(widget);
 }
+#endif
 
 /*!
     \internal
@@ -256,7 +268,7 @@
     const QString &section,
     HbWidgetLoader::LayoutDefinition *&layoutDef )
 {
     // check in the client side cache if the vector of meshitems is present.
     QString key (fileName + name + section);
     if (clientLayoutDefsCache()->contains(key)){
         // present in the client cache.
@@ -280,10 +292,12 @@
     }
 
     // get the shared layout definition address.
+#ifdef HB_USETHEMESERVER
     layoutDef = HbThemeClient::global()->getSharedLayoutDefs(fileName, name, section);
     if (layoutDef) {
         clientLayoutDefsCache()->insert(key, layoutDef);
     }
+#endif
     return true;
 }
@@ -51,7 +56,7 @@
 #define hbInstance (HbInstance::instance())
 
-// cache at the client side to store the mesh items.
+// cache at the client side to store the anchor items.
 // key used here is the filename+layoutname+sectionname.
 
@@ -256,7 +268,7 @@
     HbWidgetLoader::LayoutDefinition *&layoutDef )
 {
-    // check in the client side cache if the vector of meshitems is present.
+    // check in the client side cache if the vector of anchor items is present.
     QString key (fileName + name + section);
     if (clientLayoutDefsCache()->contains(key)){